/****************************************************************************
** mainwin.h - the main window.  holds contactlist and buttons.
** Copyright (C) 2001, 2002  Justin Karneges
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
**
****************************************************************************/

#ifndef MAINWIN_H
#define MAINWIN_H

#include<qmainwindow.h>
#include<qmap.h>
#include"xmpp_types.h"
#include"contactview.h"

class PsiToolBar;

class PsiCon;
class PsiAccount;
class QIconSet;

class QAction;
class QLabel;
class QVBoxLayout;

class MPushButton;
class PopupAction;
class MLabel;
class MTray;
class MAction;

class MainWin : public QMainWindow
{
	Q_OBJECT
public:
	MainWin(bool onTop, bool asTool, PsiCon *, const char *name=0);
	~MainWin();

	void setWindowOpts(bool onTop, bool asTool);
	void setUseDock(bool);
	void setInfo(const QString &);
	void setUsingSSL(bool);

	QVBoxLayout *vb_main;

	ContactView *cvlist;
	MLabel *lb_info;
	QLabel *lb_ssl;
	bool usingSSL;

	PsiCon *psi;

	Anim *nextAnim;
	int nextAmount;

	QMap<QString, QAction*> actions;

	PsiToolBar *toolbars[64];

	void buildToolbars();
	void saveToolbarsPositions();

private:
	bool onTop, asTool;
	QPopupMenu *statusMenu, *optionsMenu;
	int sbState;
	QString nickname;
	MTray *tray;
	QPopupMenu *trayMenu;
	QString statusTip;

	MAction *lw_act, *add_act, *man_act, *actBrowse, *actDisco;

	PopupAction *optionsButton, *statusButton;
	
	QAction *showOffline, *showAway, *showAgents;
	
	QAction *actReadme, *actAbout, *actAboutQt, *actNewMessage, 
		*actJoinGroupchat, *actAccountSetup, *actOptions, 
		*actChangeProfile, *actPlaySounds, *actQuit;

	bool askQuit();

	void updateCaption();
	void setToolbarIcons();
	void updateTray();

	QString infoString;

protected:
	void closeEvent(QCloseEvent *);
	void keyPressEvent(QKeyEvent *);

signals:
	void statusChanged(int);
	void changeProfile();
	void blankMessage();
	void closeProgram();
	void doOptions();
	void doManageAccounts();
	void doGroupChat();
	void doFileSharing();
	void accountInfo();
	void recvNextEvent();

private slots:
	void buildStatusMenu();
	void buildOptionsMenu();
	void buildTrayMenu();

	void activatedStatusMenu(int);
	void activatedOptionsMenu(int);

	void trayClicked(const QPoint &, int);
	void trayDoubleClicked();
	void trayShow();
	void trayHide();

	void doRecvNextEvent();
	void statusClicked(int);
	void tryCloseProgram();

	void numAccountsChanged();
	void testme();
	void activatedAccOption(PsiAccount *, int);

	void actReadmeActivated ();
	void actAboutActivated ();
	void actAboutQtActivated ();
	void actPlaySoundsActivated ();

	bool showDockMenu(const QPoint &);

public slots:
	void showNoFocus();

	void decorateButton(int);
	void updateReadNext(Anim *nextAnim, int nextAmount);

	void optionsUpdate();

private:
	int lastStatus;

	QString numEventsString(int) const;
};

#endif
